@@ -64,7 +64,9 @@
 #include "SpecFile.h"
 #include "SpecFileUtilities.h"
 #include "StringUtilities.h"
+#include "UbuntuMessage.h"
 #include "WuQFileDialog.h"
+#include "QtTextEditDialog.h"
 
 #define CARET_MAIN_FLAG
 #include "global_variables.h"
@@ -523,10 +525,13 @@ main(int argc, char* argv[])
    //
    // needed for static linking to have JPEG support
    //
+#ifndef UBUNTU
+#if QT_VERSION < 0x040600
    Q_IMPORT_PLUGIN(qjpeg) //QJpegPlugin)
    Q_IMPORT_PLUGIN(qgif)  //QGifPlugin)
    Q_IMPORT_PLUGIN(qtiff) //QTiffPlugin)
-
+#endif //QT_VERSION
+#endif
    //
    // Set the locale to prevent crashes due to non-english date formats
    //
@@ -607,6 +612,14 @@ main(int argc, char* argv[])
    app.setGuiMainWindow(theMainWindow);
 #endif
 
+#ifdef UBUNTU
+   QtTextEditDialog* te = new QtTextEditDialog(theMainWindow, true, true);
+   te->setWindowTitle("UBUNTU WARNING");
+   te->setMinimumSize(600, 600);
+   te->setText(UbuntuMessage::getWarningMessage());
+   te->exec();                    
+#endif UBUNTU
+
    if (initialSpecFiles.empty() == false) {
       if (QFile::exists(initialSpecFiles[0]) == false) {
          std::cerr << "The spec file " << initialSpecFiles[0].toAscii().constData() 
@@ -723,6 +736,6 @@ main(int argc, char* argv[])
    //catch (std::bad_alloc) {
    //   std::cout << "Out of memory (bad_alloc) " << std::endl;
    //}
-      
+   theMainWindow->hide();//keeps paint events from causing assertion error in close
    return result;
 }
