@@ -364,6 +364,12 @@ BrainModelSurfaceMetricAnovaTwoWay::executeClusterSearch() throw (BrainModelAlgo
       findClusters(shuffleStatisticalMapShapeFile, shuffleFMapClusters, "Finding Clusters in Shuffled F-Map", 
                    -1, true);
       
+      //
+      // Set pValue for shuffled T-Map
+      // 
+      setRandomizedClusterPValues(*shuffleStatisticalMapShapeFile,
+                               shuffleFMapClusters);
+                               
       //
       // Find area of the "P-Value" cluster in the shuffled F-Map
       //
@@ -386,13 +392,13 @@ BrainModelSurfaceMetricAnovaTwoWay::executeClusterSearch() throw (BrainModelAlgo
          int cnt = shuffleFMapClusters.size() - 1;
          if (shuffleFMapClusters.empty() == false) {
             if (fMapCluster.areaCorrected > shuffleFMapClusters[0].areaCorrected) {
-               cnt = 0;
+               cnt = 1;
             }
             else {
                for (unsigned int j = 0; j < shuffleFMapClusters.size() - 1; j++) {
                   if ((fMapCluster.areaCorrected < shuffleFMapClusters[j].areaCorrected) &&
                       (fMapCluster.areaCorrected >= shuffleFMapClusters[j+1].areaCorrected)) {
-                     cnt = j;
+                     cnt = j + 2;
                   }
                }
             }
