@@ -282,6 +282,12 @@ BrainModelSurfaceMetricOneAndPairedTTest::executeClusterSearch() throw (BrainMod
    std::vector<Cluster> shuffleTMapClusters;
    findClusters(shuffleStatisticalMapShapeFile, shuffleTMapClusters, "Finding Clusters in Permuted T-Map", -1, true);
    
+   //
+   // Set pValue for shuffled T-Map
+   // 
+   setRandomizedClusterPValues(*shuffleStatisticalMapShapeFile,
+                               shuffleTMapClusters);
+                               
    //
    // Find area of the "P-Value" cluster in the permuted T-Map
    //
@@ -304,13 +310,13 @@ BrainModelSurfaceMetricOneAndPairedTTest::executeClusterSearch() throw (BrainMod
       int cnt = shuffleTMapClusters.size() - 1;
       if (shuffleTMapClusters.empty() == false) {
          if (tMapCluster.areaCorrected > shuffleTMapClusters[0].areaCorrected) {
-            cnt = 0;
+            cnt = 1;
          }
          else {
             for (unsigned int j = 0; j < shuffleTMapClusters.size() - 1; j++) {
                if ((tMapCluster.areaCorrected < shuffleTMapClusters[j].areaCorrected) &&
                    (tMapCluster.areaCorrected >= shuffleTMapClusters[j+1].areaCorrected)) {
-                  cnt = j;
+                  cnt = j + 2;
                }
             }
          }
