@@ -782,7 +782,7 @@ BrainModelSurfaceOverlay::showScene(const SceneFile::Scene& scene,
                int endSurface   = brainSet->getNumberOfBrainModels();
                if (surfaceName != SceneFile::SceneInfo::getDefaultSurfacesName()) {
                   endSurface = 0;
-                  const BrainModelSurface* bms = brainSet->getBrainModelSurfaceWithFileName(surfaceName);
+                  const BrainModelSurface* bms = brainSet->getBrainModelSurfaceWithCoordinateFileName(surfaceName);
                   if (bms != NULL) {
                      startSurface = brainSet->getBrainModelIndex(bms);
                      if (startSurface >= 0) {
