@@ -754,7 +754,7 @@ DisplaySettingsNodeAttributeFile::showSceneSelectedColumns(const SceneFile::Scen
             //
             if (surfaceName != SceneFile::SceneInfo::getDefaultSurfacesName()) {
                endSurface = 0;
-               const BrainModelSurface* bms = brainSet->getBrainModelSurfaceWithFileName(surfaceName);
+               const BrainModelSurface* bms = brainSet->getBrainModelSurfaceWithCoordinateFileName(surfaceName);
                if (bms != NULL) {
                   startSurface = brainSet->getBrainModelIndex(bms);
                   if (startSurface >= 0) {
