@@ -38,14 +38,18 @@
 #include "StringUtilities.h"
 #include "VolumeFile.h"
 
+#include "CommandCaretFileCopy.h"
 #include "CommandCaretFileNamingUnitTesting.h"  
 #include "CommandCaretHelpCreateHtmlIndexFile.h"
+#include "CommandCiftiCorrelationMatrix.h"
 #include "CommandColorFileAddColor.h"
 #include "CommandColorFileCreateMissingColors.h"
 #include "CommandConvertDataFileToCaret6.h"
 #include "CommandConvertSpecFileToCaret6.h"
+#include "CommandCreateCiftiDenseTimeseries.h"
 #include "CommandDataFileCompare.h"
 #include "CommandDeformationMapApply.h"
+#include "CommandDeformationMapApplyGenericNames.h"
 #include "CommandDeformationMapCreate.h"
 #include "CommandDeformationMapPathUpdate.h"
 #include "CommandExtend.h"
@@ -70,7 +74,13 @@
 #include "CommandMetricComposite.h"
 #include "CommandMetricCompositeIdentifiedColumns.h"
 #include "CommandMetricCorrelationCoefficientMap.h"
+#include "CommandMetricExtrema.h"
 #include "CommandMetricFileCreate.h"
+#include "CommandMetricGradient.h"
+#include "CommandMetricGradientAll.h"
+#include "CommandMetricROIGradient.h"
+#include "CommandMetricROIMask.h"
+#include "CommandMetricROISmoothing.h"
 #include "CommandMetricInGroupDifference.h"
 #include "CommandMetricInformation.h"
 #include "CommandMetricMath.h"
@@ -82,6 +92,7 @@
 #include "CommandMetricStatisticsAnovaOneWay.h"
 #include "CommandMetricStatisticsAnovaTwoWay.h"
 #include "CommandMetricStatisticsCoordinateDifference.h"
+#include "CommandMetricCorrelationMatrix.h"
 #include "CommandMetricStatisticsInterhemisphericClusters.h"
 #include "CommandMetricStatisticsKruskalWallis.h"
 #include "CommandMetricStatisticsLeveneMap.h"
@@ -94,6 +105,7 @@
 #include "CommandMetricStatisticsTMap.h"
 #include "CommandMetricStatisticsTwoSampleTTest.h"
 #include "CommandMetricStatisticsZMap.h"
+#include "CommandMetricTranspose.h"
 #include "CommandMetricTwinComparison.h"
 #include "CommandMetricTwinPairedDataDiffs.h"
 #include "CommandPaintAddColumns.h"
@@ -102,6 +114,8 @@
 #include "CommandPaintComposite.h"
 #include "CommandPaintDilation.h"
 #include "CommandPaintFileCreate.h"
+#include "CommandPaintLabelNameUpdate.h"
+#include "CommandPaintSetColumnName.h"
 #include "CommandPreferencesFileSettings.h"
 #include "CommandSceneCreate.h"
 #include "CommandScriptComment.h"
@@ -128,6 +142,7 @@
 #include "CommandSurfaceAlignToStandardOrientation.h"
 #include "CommandSurfaceApplyTransformationMatrix.h"
 #include "CommandSurfaceAverage.h"
+#include "CommandSurfaceBankStraddling.h"
 #include "CommandSurfaceBorderCreateAverage.h"
 #include "CommandSurfaceBorderCreateParallelBorder.h"
 #include "CommandSurfaceBorderCutter.h"
@@ -135,6 +150,7 @@
 #include "CommandSurfaceBorderDrawAroundROI.h"
 #include "CommandSurfaceBorderDrawGeodesic.h"
 #include "CommandSurfaceBorderDrawMetric.h"
+#include "CommandSurfaceBorderFileMerge.h"
 #include "CommandSurfaceBorderToPaint.h"
 #include "CommandSurfaceBorderIntersection.h"
 #include "CommandSurfaceBorderLandmarkIdentification.h"
@@ -166,8 +182,10 @@
 #include "CommandSurfaceFociStudyValidate.h"
 #include "CommandSurfaceFociUnprojection.h"
 #include "CommandSurfaceGenerateInflated.h"
+#include "CommandSurfaceGeodesic.h"
 #include "CommandSurfaceInflate.h"
 #include "CommandSurfaceInformation.h"
+#include "CommandSurfaceNormals.h"
 #include "CommandSurfacePlaceFociAtLimits.h"
 #include "CommandSurfacePlaceFociAtExtremum.h"
 #include "CommandSurfaceRegionOfInterestSelection.h"
@@ -180,6 +198,8 @@
 #include "CommandSurfaceRoiShapeMeasures.h"
 #include "CommandSurfaceRoiStatisticalReport.h"
 #include "CommandSurfaceSmoothing.h"
+#include "CommandSurfaceSphere.h"
+#include "CommandSurfaceSphereProjectUnproject.h"
 #include "CommandSurfaceSphericalMultiResMorphing.h"
 #include "CommandSurfaceSulcalDepth.h"
 #include "CommandSurfaceSulcalIdentificationProbabilistic.h"
@@ -189,6 +209,7 @@
 #include "CommandSurfaceToSegmentationVolume.h"
 #include "CommandSurfaceToVolume.h"
 #include "CommandSurfaceTopologyDisconnectNodes.h"
+#include "CommandSurfaceTopologyFixOrientation.h"
 #include "CommandSurfaceTopologyNeighbors.h"
 #include "CommandSurfaceTopologyReport.h"
 #include "CommandSurfaceTransformToStandardView.h"
@@ -200,6 +221,7 @@
 #include "CommandVerify.h"
 #include "CommandVersion.h"
 #include "CommandVolumeAnatomyPeaks.h"
+#include "CommandVolumeAtlasResamplingAndSmoothing.h"
 #include "CommandVolumeBiasCorrection.h"
 #include "CommandVolumeBlur.h"
 #include "CommandVolumeClassifyIntensities.h"
@@ -244,6 +266,9 @@
 #include "CommandVolumeResample.h"
 #include "CommandVolumeRescaleVoxels.h"
 #include "CommandVolumeResize.h"
+#include "CommandVolumeROIGradient.h"
+#include "CommandVolumeROIMinima.h"
+#include "CommandVolumeROISmoothing.h"
 #include "CommandVolumeScale0to255.h"
 #include "CommandVolumeScalePercent0to255.h"
 #include "CommandVolumeSculpt.h"
@@ -293,14 +318,18 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
 {
    commandsOut.clear();
    
+   commandsOut.push_back(new CommandCaretFileCopy);
    commandsOut.push_back(new CommandCaretFileNamingUnitTesting);
    commandsOut.push_back(new CommandCaretHelpCreateHtmlIndexFile);
+   commandsOut.push_back(new CommandCiftiCorrelationMatrix);
    commandsOut.push_back(new CommandColorFileAddColor);
    commandsOut.push_back(new CommandColorFileCreateMissingColors);
    commandsOut.push_back(new CommandConvertDataFileToCaret6);
    commandsOut.push_back(new CommandConvertSpecFileToCaret6);
+   commandsOut.push_back(new CommandCreateCiftiDenseTimeseries);
    commandsOut.push_back(new CommandDataFileCompare);
    commandsOut.push_back(new CommandDeformationMapApply);
+   commandsOut.push_back(new CommandDeformationMapApplyGenericNames);
    commandsOut.push_back(new CommandDeformationMapCreate);
    commandsOut.push_back(new CommandDeformationMapPathUpdate);
    commandsOut.push_back(new CommandExtend);
@@ -325,12 +354,19 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandMetricComposite);
    commandsOut.push_back(new CommandMetricCompositeIdentifiedColumns);
    commandsOut.push_back(new CommandMetricCorrelationCoefficientMap);
+   commandsOut.push_back(new CommandMetricCorrelationMatrix);
+   commandsOut.push_back(new CommandMetricExtrema);
    commandsOut.push_back(new CommandMetricFileCreate);
+   commandsOut.push_back(new CommandMetricGradient);
+   commandsOut.push_back(new CommandMetricGradientAll);
    commandsOut.push_back(new CommandMetricInGroupDifference);
    commandsOut.push_back(new CommandMetricInformation);
    commandsOut.push_back(new CommandMetricMath);
    commandsOut.push_back(new CommandMetricMathPostfix);
    commandsOut.push_back(new CommandMetricMultipleCorrelationCoefficientMap);
+   commandsOut.push_back(new CommandMetricROIGradient);
+   commandsOut.push_back(new CommandMetricROIMask);
+   commandsOut.push_back(new CommandMetricROISmoothing);
    commandsOut.push_back(new CommandMetricSetColumnName);
    commandsOut.push_back(new CommandMetricSetColumnToScalar);
    commandsOut.push_back(new CommandMetricSmoothing);
@@ -349,6 +385,7 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandMetricStatisticsTMap);
    commandsOut.push_back(new CommandMetricStatisticsTwoSampleTTest);
    commandsOut.push_back(new CommandMetricStatisticsZMap);
+   commandsOut.push_back(new CommandMetricTranspose);
    commandsOut.push_back(new CommandMetricTwinComparison);
    commandsOut.push_back(new CommandMetricTwinPairedDataDiffs);
    commandsOut.push_back(new CommandPaintAddColumns);
@@ -357,6 +394,8 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandPaintComposite);
    commandsOut.push_back(new CommandPaintDilation);
    commandsOut.push_back(new CommandPaintFileCreate);
+   commandsOut.push_back(new CommandPaintLabelNameUpdate);
+   commandsOut.push_back(new CommandPaintSetColumnName);
    commandsOut.push_back(new CommandPreferencesFileSettings);
    commandsOut.push_back(new CommandSceneCreate);
    commandsOut.push_back(new CommandScriptComment);
@@ -383,6 +422,7 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandSurfaceAlignToStandardOrientation);
    commandsOut.push_back(new CommandSurfaceApplyTransformationMatrix);
    commandsOut.push_back(new CommandSurfaceAverage);
+   commandsOut.push_back(new CommandSurfaceBankStraddling);
    commandsOut.push_back(new CommandSurfaceBorderCreateAverage);
    commandsOut.push_back(new CommandSurfaceBorderCreateParallelBorder);
    commandsOut.push_back(new CommandSurfaceBorderCutter);
@@ -390,6 +430,7 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandSurfaceBorderDrawAroundROI);
    commandsOut.push_back(new CommandSurfaceBorderDrawGeodesic);
    commandsOut.push_back(new CommandSurfaceBorderDrawMetric);
+   commandsOut.push_back(new CommandSurfaceBorderFileMerge);
    commandsOut.push_back(new CommandSurfaceBorderToPaint);
    commandsOut.push_back(new CommandSurfaceBorderIntersection);
    commandsOut.push_back(new CommandSurfaceBorderLandmarkIdentification);
@@ -421,9 +462,11 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandSurfaceFociStudyValidate);
    commandsOut.push_back(new CommandSurfaceFociUnprojection);
    commandsOut.push_back(new CommandSurfaceGenerateInflated);
+   commandsOut.push_back(new CommandSurfaceGeodesic);
    commandsOut.push_back(new CommandSurfaceIdentifySulci);
    commandsOut.push_back(new CommandSurfaceInflate);
    commandsOut.push_back(new CommandSurfaceInformation);
+   commandsOut.push_back(new CommandSurfaceNormals);
    commandsOut.push_back(new CommandSurfacePlaceFociAtExtremum);
    commandsOut.push_back(new CommandSurfacePlaceFociAtLimits);
    commandsOut.push_back(new CommandSurfaceRegionOfInterestSelection);
@@ -435,6 +478,7 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandSurfaceRoiNodeAreas);
    commandsOut.push_back(new CommandSurfaceRoiShapeMeasures);
    commandsOut.push_back(new CommandSurfaceRoiStatisticalReport);
+   commandsOut.push_back(new CommandSurfaceSphere());
    commandsOut.push_back(new CommandSurfaceSulcalDepth);
    commandsOut.push_back(new CommandSurfaceSulcalIdentificationProbabilistic);
    commandsOut.push_back(new CommandSurfaceToCArrays);
@@ -442,7 +486,9 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandSurfaceToSegmentationVolume);
    commandsOut.push_back(new CommandSurfaceToVolume);
    commandsOut.push_back(new CommandSurfaceSmoothing);
+   commandsOut.push_back(new CommandSurfaceSphereProjectUnproject);
    commandsOut.push_back(new CommandSurfaceSphericalMultiResMorphing);
+   commandsOut.push_back(new CommandSurfaceTopologyFixOrientation);
    commandsOut.push_back(new CommandSurfaceTopologyDisconnectNodes);
    commandsOut.push_back(new CommandSurfaceTopologyNeighbors);
    commandsOut.push_back(new CommandSurfaceTopologyReport);
@@ -455,6 +501,7 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandVerify);
    commandsOut.push_back(new CommandVersion);
    commandsOut.push_back(new CommandVolumeAnatomyPeaks);
+   commandsOut.push_back(new CommandVolumeAtlasResamplingAndSmoothing);
    commandsOut.push_back(new CommandVolumeBiasCorrection);
    commandsOut.push_back(new CommandVolumeBlur);
    commandsOut.push_back(new CommandVolumeClassifyIntensities);
@@ -499,6 +546,9 @@ CommandBase::getAllCommandsUnsorted(std::vector<CommandBase*>& commandsOut)
    commandsOut.push_back(new CommandVolumeResample);
    commandsOut.push_back(new CommandVolumeRescaleVoxels);
    commandsOut.push_back(new CommandVolumeResize);
+   commandsOut.push_back(new CommandVolumeROIGradient);
+   commandsOut.push_back(new CommandVolumeROIMinima);
+   commandsOut.push_back(new CommandVolumeROISmoothing);
    commandsOut.push_back(new CommandVolumeScale0to255);
    commandsOut.push_back(new CommandVolumeScalePercent0to255);
    commandsOut.push_back(new CommandVolumeSculpt);
