@@ -1528,6 +1528,9 @@ CellFile::readFileData(QFile& file,
       case FILE_FORMAT_XML_GZIP_BASE64:
          throw FileException(filename, "Reading XML GZip Base64 not supported.");
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         throw FileException(filename, "Reading XML External Binary not supported.");
+         break;      
       case FILE_FORMAT_OTHER:
          throw FileException(filename, "Reading in Other format not supported.");
          break;
@@ -1591,6 +1594,9 @@ CellFile::writeFileData(QTextStream& stream,
       case FILE_FORMAT_XML_GZIP_BASE64:
          throw FileException(filename, "Writing XML GZip Base64 not supported.");
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         throw FileException(filename, "Writing XML External Binary not supported.");
+         break;      
       case FILE_FORMAT_OTHER:
          throw FileException(filename, "Writing in Other format not supported.");
          break;
