@@ -578,18 +578,21 @@ DeformationFieldFile::readFileData(QFile& /*file*/,
          }
          break;
       case FILE_FORMAT_XML:
-         throw FileException(filename, "Writing in XML format not supported.");
+         throw FileException(filename, "Reading in XML format not supported.");
       case FILE_FORMAT_XML_BASE64:
          throw FileException(filename, "Reading XML Base64 not supported.");
          break;
       case FILE_FORMAT_XML_GZIP_BASE64:
          throw FileException(filename, "Reading XML GZip Base64 not supported.");
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         throw FileException(filename, "Reading XML External Binary not supported.");
+         break;      
       case FILE_FORMAT_OTHER:
-         throw FileException(filename, "Writing in Other format not supported.");
+         throw FileException(filename, "Reading in Other format not supported.");
          break;
       case FILE_FORMAT_COMMA_SEPARATED_VALUE_FILE:
-         throw FileException(filename, "Writing Comma Separated Value File Format not supported.");
+         throw FileException(filename, "Reading Comma Separated Value File Format not supported.");
          break;
    }         
 }
@@ -680,6 +683,9 @@ DeformationFieldFile::writeFileData(QTextStream& stream,
       case FILE_FORMAT_XML_GZIP_BASE64:
          throw FileException(filename, "XML GZip Base64 not supported.");
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         throw FileException(filename, "Writing XML External Binary not supported.");
+         break;      
       case FILE_FORMAT_OTHER:
          throw FileException(filename, "Writing in Other format not supported.");
          break;
