@@ -105,7 +105,7 @@ DeformationMapFile::compareFileForUnitTesting(const AbstractFile* af,
             messageOut += "ERROR: There are tiles that do not match between the files.\n";
             return false;
          }
-         const float diff = std::fabs(areasMe[i] != areasOther[i]);
+         const float diff = std::fabs((float)(areasMe[i] != areasOther[i]));
          if (diff > tolerance) {
             messageOut +="ERROR: tile areas are not within tolerance.";
             return false;
@@ -807,6 +807,9 @@ DeformationMapFile::readFileData(QFile& /*file*/, QTextStream& stream, QDataStre
       case FILE_FORMAT_XML_GZIP_BASE64:
          throw FileException(filename, "Reading XML GZip Base64 not supported.");
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         throw FileException(filename, "Reading XML External Binary not supported.");
+         break;      
       case FILE_FORMAT_OTHER:
          throw FileException(filename, "Reading in Other format not supported.");
          break;
@@ -1062,6 +1065,9 @@ DeformationMapFile::writeFileData(QTextStream& stream, QDataStream& binStream,
       case FILE_FORMAT_XML_GZIP_BASE64:
          throw FileException(filename, "XML GZip Base64 not supported.");
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         throw FileException(filename, "Writing XML External Binary not supported.");
+         break;      
       case FILE_FORMAT_OTHER:
          throw FileException(filename, "Writing in Other format not supported.");
          break;
