@@ -24,6 +24,8 @@
 /*LICENSE_END*/
 
 #include <iostream>
+
+#include "PaintFile.h"
 #include <set>
 #include <sstream>
 
@@ -38,6 +40,9 @@
 #include "GiftiDataArrayFileStreamReader.h"
 #include "GiftiDataArrayFileSaxReader.h"
 
+#include "MetricFile.h"
+#include "SurfaceShapeFile.h"
+#include "PaintFile.h"
 #include "StringUtilities.h"
 
 /**
@@ -74,11 +79,13 @@ GiftiDataArrayFile::GiftiDataArrayFile(const QString& descriptiveName,
       setFileReadWriteType(FILE_FORMAT_XML, FILE_IO_READ_AND_WRITE);
       setFileReadWriteType(FILE_FORMAT_XML_BASE64, FILE_IO_READ_AND_WRITE);
       setFileReadWriteType(FILE_FORMAT_XML_GZIP_BASE64, FILE_IO_READ_AND_WRITE);
+      setFileReadWriteType(FILE_FORMAT_XML_EXTERNAL_BINARY, FILE_IO_READ_AND_WRITE);
    }
    else {
       setFileReadWriteType(FILE_FORMAT_XML, FILE_IO_READ_ONLY);
       setFileReadWriteType(FILE_FORMAT_XML_BASE64, FILE_IO_READ_ONLY);
       setFileReadWriteType(FILE_FORMAT_XML_GZIP_BASE64, FILE_IO_READ_ONLY);
+      setFileReadWriteType(FILE_FORMAT_XML_EXTERNAL_BINARY, FILE_IO_READ_ONLY);
    }
    //
    
@@ -130,6 +137,7 @@ GiftiDataArrayFile::GiftiDataArrayFile()
    setFileReadWriteType(FILE_FORMAT_XML_BASE64, FILE_IO_NONE);
    setFileReadWriteType(FILE_FORMAT_XML_GZIP_BASE64, FILE_IO_NONE);
 #endif // HAVE_VTK
+   setFileReadWriteType(FILE_FORMAT_XML_EXTERNAL_BINARY, FILE_IO_READ_AND_WRITE);
 }
 
 /**
@@ -167,7 +175,11 @@ GiftiDataArrayFile::copyHelperGiftiDataArrayFile(const GiftiDataArrayFile& nndf)
    defaultDataArrayIntent = nndf.defaultDataArrayIntent;
    dataAreIndicesIntoLabelTable = nndf.dataAreIndicesIntoLabelTable;
    numberOfNodesForSparseNodeIndexFile = nndf.numberOfNodesForSparseNodeIndexFile;
-   
+
+   int numArrays = this->getNumberOfDataArrays();
+   for (int i = (numArrays - 1); i >= 0; i--) {
+      this->removeDataArray(i);
+   }
    for (unsigned int i = 0; i < nndf.dataArrays.size(); i++) {
       addDataArray(new GiftiDataArray(*nndf.dataArrays[i]));
    }
@@ -731,7 +743,8 @@ GiftiDataArrayFile::appendLabelDataHelper(const GiftiDataArrayFile& naf,
                   oldIndicesToNewIndicesTable[indx] = -2;
                }
                else {
-                  std::cout << "WARNING Invalid label index set to zero: " << indx << std::endl;
+                  std::cout << "WARNING Invalid label index set to zero: " << indx 
+                            << " of " << numLabelsNew << " labels." << std::endl;
                   dataPtr[i] = 0;
                }
             }
@@ -831,6 +844,9 @@ GiftiDataArrayFile::readFileData(QFile& file,
       case FILE_FORMAT_XML_GZIP_BASE64:
          readFileDataXML(file);
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         readFileDataXML(file);
+         break;
       case FILE_FORMAT_OTHER:
          readLegacyFileData(file, stream, binStream);
          break;
@@ -843,6 +859,18 @@ GiftiDataArrayFile::readFileData(QFile& file,
       procesNiftiIntentNodeIndexArrays();
    }
 
+   //
+   // Force metric, paint, shape data arrays to float
+   //
+   if ((dynamic_cast<MetricFile*>(this) != NULL) ||
+       (dynamic_cast<PaintFile*>(this) != NULL) ||
+       (dynamic_cast<SurfaceShapeFile*>(this) != NULL)) {
+      int numDataArrays = this->getNumberOfDataArrays();
+      for (int i = 0; i < numDataArrays; i++) {
+         this->getDataArray(i)->convertToDataType(this->defaultDataType);
+      }
+   }
+
    this->validateDataArrays();
 }
 
@@ -871,6 +899,9 @@ GiftiDataArrayFile::writeFileData(QTextStream& stream,
       case FILE_FORMAT_XML_GZIP_BASE64:
          writeFileDataXML(stream);
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         writeFileDataXML(stream);
+         break;
       case FILE_FORMAT_OTHER:
          writeLegacyFileData(stream, binStream);
          break;
@@ -925,6 +956,7 @@ GiftiDataArrayFile::readFileDataXML(QFile& file) throw (FileException)
          // Create a data stream
          //   
          QDataStream stream(&file);
+		 stream.setVersion(QDataStream::Qt_4_3);
          
          //
          // buffer for data read
@@ -985,7 +1017,20 @@ GiftiDataArrayFile::readFileDataXML(QFile& file) throw (FileException)
    const GiftiMetaData::MetaDataContainer* data = metaData.getMetaData();
    for (GiftiMetaData::ConstMetaDataIterator iter = data->begin(); iter != data->end(); iter++) {
       setHeaderTag(iter->first, iter->second);
-   }   
+   }
+
+   //
+   // Some GIFTI Label files have just a few labels with very large indices
+   // which causes many empty indices in the LabelTable.  Cleaning up
+   // the label table compacts these into sequential indices starting
+   // at zero.
+   //
+   //PaintFile* pf = dynamic_cast<PaintFile*>(this);
+   //if (pf != NULL) {
+   //   if (pf->getNumberOfPaintNames() > 1000) {
+   //      pf->cleanUpPaintNames();
+   //   }
+   //}
 }
 
 /*
@@ -1022,6 +1067,7 @@ GiftiDataArrayFile::readFileDataXML(QFile& file) throw (FileException)
       // Create a data stream
       //   
       QDataStream stream(&file);
+	  stream.setVersion(QDataStream::Qt_4_3);
       
       //
       // buffer for data read
@@ -1086,7 +1132,7 @@ GiftiDataArrayFile::readFileDataXML(QFile& file) throw (FileException)
 */
 
 /**
- * write the XML file.
+ * write the XML file. 
  */
 void 
 GiftiDataArrayFile::writeFileDataXML(QTextStream& stream) throw (FileException)
@@ -1109,6 +1155,9 @@ GiftiDataArrayFile::writeFileDataXML(QTextStream& stream) throw (FileException)
       case FILE_FORMAT_XML_GZIP_BASE64:
          encoding = GiftiDataArray::ENCODING_INTERNAL_COMPRESSED_BASE64_BINARY;
          break;
+      case FILE_FORMAT_XML_EXTERNAL_BINARY:
+         encoding = GiftiDataArray::ENCODING_EXTERNAL_FILE_BINARY;
+         break;
       case FILE_FORMAT_OTHER:
          break;
       case FILE_FORMAT_COMMA_SEPARATED_VALUE_FILE:
@@ -1138,6 +1187,21 @@ GiftiDataArrayFile::writeFileDataXML(QTextStream& stream) throw (FileException)
           << ">" << "\n";
    int indent = 0;
 
+   //
+   // External binary file.
+   //
+   QString externalBinaryFileName;
+   long externalBinaryFileDataOffset = 0;
+   std::ofstream* externalBinaryOutputStream = NULL;
+   if (encoding == GiftiDataArray::ENCODING_EXTERNAL_FILE_BINARY) {
+       externalBinaryFileName = getFileNameNoPath() + ".data";
+       externalBinaryOutputStream = new std::ofstream(externalBinaryFileName.toAscii().constData(),
+                                                      std::ofstream::binary);
+       if (externalBinaryOutputStream == NULL) {
+          throw FileException("Unable to open " + externalBinaryFileName + " for output.");
+       }
+   }
+   
 #ifdef CARET_FLAG
    //
    // copy the Abstract File header into this file's metadata 
@@ -1170,11 +1234,20 @@ GiftiDataArrayFile::writeFileDataXML(QTextStream& stream) throw (FileException)
 #ifdef CARET_FLAG
       dataArrays[i]->setEncoding(encoding);
 #endif // CARET_FLAG
-      dataArrays[i]->writeAsXML(stream, indent);
+      if (externalBinaryOutputStream != NULL) {
+          externalBinaryFileDataOffset = externalBinaryOutputStream->tellp();
+      }
+      dataArrays[i]->setExternalFileInformation(externalBinaryFileName,
+                                                externalBinaryFileDataOffset);
+      dataArrays[i]->writeAsXML(stream, indent, externalBinaryOutputStream);
    }
    indent--;
    
    stream << "</" << GiftiCommon::tagGIFTI << ">" << "\n";
+   
+   if (externalBinaryOutputStream != NULL) {
+      externalBinaryOutputStream->close();
+   }
 }      
 
 /**
