@@ -26,11 +26,17 @@
 
 #include <iostream>
 
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
 #include <QTextStream>
+#include <QXmlDefaultHandler>
 
+#include "DebugControl.h"
 #include "GiftiCommon.h"
 #include "GiftiDataArrayFile.h"
 #include "GiftiDataArrayFileStreamReader.h"
+#include "GiftiDataArrayReadListener.h"
 #include "GiftiLabelTable.h"
 #include "GiftiMatrix.h"
 #include "GiftiMetaData.h"
@@ -44,8 +50,39 @@ GiftiDataArrayFileStreamReader::GiftiDataArrayFileStreamReader(QFile* file,
    : QXmlStreamReader(file)
 {
    giftiFile = giftiFileIn;
+   this->numberOfDataArraysInFile = 0;
+   this->dataArrayReadIndex = 0;
+   this->giftiDataArrayReadListener = NULL;
 }
 
+/// For incrementally reading arrays
+/// the listener is called with each array as it is read and
+/// it is the responsibility of the listener to delete the array.
+void
+GiftiDataArrayFileStreamReader::readFileAndReportDataArraysAsTheyAreRead(
+      const QString& filename,
+      GiftiDataArrayReadListener* giftiDataArrayReadListenerIn) throw (FileException)
+{
+   QFile file(filename);
+   if (file.open(QIODevice::ReadOnly)) {
+      try {
+         GiftiDataArrayFile gdaf;
+         GiftiDataArrayFileStreamReader streamReader(&file, &gdaf);
+         streamReader.giftiDataArrayReadListener = giftiDataArrayReadListenerIn;
+         streamReader.readData();
+         file.close();
+      }
+      catch (FileException e) {
+         file.close();
+         throw FileException(e);
+      }
+   }
+   else {
+      throw FileException(filename, file.errorString());
+   }
+}
+
+
 /**
  * destructor.
  */
@@ -86,7 +123,16 @@ GiftiDataArrayFileStreamReader::readData() throw (FileException)
                raiseError("GIFTI file version unknown.");
             }
             const float version = versionString.toFloat();
-            
+
+            /*
+             * Number of Data Arrays.
+             */
+            const QString numberOfDataArraysString = attributes().value(GiftiCommon::attNumberOfDataArrays).toString();
+            if (numberOfDataArraysString.isEmpty()) {
+               raiseError("GIFTI file number of data arrays is missing.");
+            }
+            this->numberOfDataArraysInFile = numberOfDataArraysString.toInt();
+
             if (version == 1.0) {
                readGiftiVersion1();
             }
@@ -103,6 +149,10 @@ GiftiDataArrayFileStreamReader::readData() throw (FileException)
                        + ".");
          }
       }
+
+      if (error()) {
+         break;
+      }
    }
    
    if (error()) {
@@ -251,7 +301,13 @@ GiftiDataArrayFileStreamReader::readLabelTable(GiftiLabelTable* labelTable)
       //
       if (isStartElement()) {
          if (name() == GiftiCommon::tagLabel) {
-            const QString indexString = attributes().value(GiftiCommon::attIndex).toString();
+            QString keyString = attributes().value(GiftiCommon::attKey).toString();
+            if (keyString == NULL) {
+               keyString = attributes().value("Index").toString();
+            }
+            else if (keyString.isEmpty()) {
+               keyString = attributes().value("Index").toString();
+            }
 
             float labelRed, labelGreen, labelBlue, labelAlpha;
             GiftiLabelTable::getDefaultColorFloat(labelRed,
@@ -262,24 +318,28 @@ GiftiDataArrayFileStreamReader::readLabelTable(GiftiLabelTable* labelTable)
             const QString redString = attributes().value(GiftiCommon::attRed).toString();
             if (redString.isEmpty() == false) {
                labelRed = StringUtilities::toFloat(redString);
+               labelTable->setHadColorsWhenRead(true);
             }
             const QString greenString = attributes().value(GiftiCommon::attGreen).toString();
             if (greenString.isEmpty() == false) {
                labelGreen = StringUtilities::toFloat(greenString);
+               labelTable->setHadColorsWhenRead(true);
             }
             const QString blueString = attributes().value(GiftiCommon::attBlue).toString();
             if (blueString.isEmpty() == false) {
                labelBlue = StringUtilities::toFloat(blueString);
+               labelTable->setHadColorsWhenRead(true);
             }
             const QString alphaString = attributes().value(GiftiCommon::attAlpha).toString();
             if (alphaString.isEmpty() == false) {
                labelAlpha = StringUtilities::toFloat(alphaString);
+               labelTable->setHadColorsWhenRead(true);
             }
 
             const QString name = readElementText();
             
             bool valid = false;
-            const int indx = indexString.toInt(&valid);
+            const int indx = keyString.toInt(&valid);
             if (valid) {
                if (indx >= 0) {
                   labelTable->setLabel(indx, name);
@@ -306,7 +366,7 @@ GiftiDataArrayFileStreamReader::readDataArray()
    const QString dimensionalityName = attributes().value(GiftiCommon::attDimensionality).toString();
    const QString encodingName = attributes().value(GiftiCommon::attEncoding).toString();
    const QString endianName = attributes().value(GiftiCommon::attEndian).toString();
-   const QString externalFileName = attributes().value(GiftiCommon::attExternalFileName).toString();
+   QString externalFileName = attributes().value(GiftiCommon::attExternalFileName).toString();
    const QString externalFileOffsetString = attributes().value(GiftiCommon::attExternalFileOffset).toString();
 
    //
@@ -351,18 +411,42 @@ GiftiDataArrayFileStreamReader::readDataArray()
    //
    // External File Offset
    //
-   int externalFileOffsetForReadingData = 0;
+   long externalFileOffsetForReadingData = 0;
    if (externalFileOffsetString.isEmpty() == false) {
       bool validOffsetFlag = false;
-      externalFileOffsetForReadingData = externalFileOffsetString.toInt(&validOffsetFlag);
+      externalFileOffsetForReadingData = externalFileOffsetString.toLong(&validOffsetFlag);
       if (validOffsetFlag == false) {
-         raiseError("File Offset is not an integer ("
+         raiseError("File Offset is not a long integer ("
                              + externalFileOffsetString
                              + ")");
          return;
       }
    }
    
+   //
+   // Determine full path to external file name
+   //
+   if (externalFileName.isEmpty() == false) {
+      if (QFileInfo(externalFileName).isAbsolute() == false) {
+          //
+          // If exernal file name path is not absolute, 
+          // use path from the gifti data file that refers
+          // to the external binary file.
+          //
+          QFileInfo fileInfo(this->giftiFile->getFileName());
+          QString fullPathName = 
+              fileInfo.absolutePath()
+              + QDir::separator()
+              + externalFileName;
+          if (DebugControl::getDebugOn()) {
+             std::cout << "External Name: " << externalFileName.toAscii().constData() << std::endl;
+             std::cout << "External Full Path: " << fullPathName.toAscii().constData() << std::endl;
+             std::cout << std::endl;
+          }
+          externalFileName = fullPathName;
+      }
+   }
+   
    //
    // Endian
    //
@@ -390,7 +474,7 @@ GiftiDataArrayFileStreamReader::readDataArray()
       const QString dimNumString = attributes().value(GiftiCommon::getAttDim(i)).toString();
       if (dimNumString.isEmpty()) {
          raiseError("Required dimension "
-                        + GiftiCommon::GiftiCommon::getAttDim(i)
+                        + GiftiCommon::getAttDim(i)
                         + " not found for DataArray"); 
          return;
       }
@@ -447,20 +531,33 @@ GiftiDataArrayFileStreamReader::readDataArray()
                      // Read the data
                      //
                      dataWasReadFlag = true;
-                     QString text = "";
-                     dataArray->readFromText(text,
-                                             endianName,
-                                             arraySubscriptingOrderForReadingArrayData,
-                                             dataTypeForReadingArrayData,
-                                             dimensionsForReadingArrayData,
-                                             encodingForReadingArrayData,
-                                             externalFileName,
-                                             externalFileOffsetForReadingData);
+                     if (this->giftiFile->getReadMetaDataOnlyFlag() == false) {
+                         QString text = "";
+                         dataArray->readFromText(text,
+                                                 endianName,
+                                                 arraySubscriptingOrderForReadingArrayData,
+                                                 dataTypeForReadingArrayData,
+                                                 dimensionsForReadingArrayData,
+                                                 encodingForReadingArrayData,
+                                                 externalFileName,
+                                                 externalFileOffsetForReadingData);
+                     }
 
                      //
                      // Add GIFTI array to GIFTI file
                      //
-                     giftiFile->addDataArray(dataArray);
+                     if (this->giftiDataArrayReadListener != NULL) {
+                        const QString errorMessage =
+                           this->giftiDataArrayReadListener->dataArrayWasRead(
+                              dataArray, this->dataArrayReadIndex, this->numberOfDataArraysInFile);
+                        if (errorMessage.isEmpty() == false) {
+                           raiseError(errorMessage);
+                        }
+                        this->dataArrayReadIndex++;
+                     }
+                     else {
+                        giftiFile->addDataArray(dataArray);
+                     }
                   }
                   catch (FileException& e) {
                      delete dataArray;
@@ -485,24 +582,37 @@ GiftiDataArrayFileStreamReader::readDataArray()
          }
          else if (elemName == GiftiCommon::tagData) {
             try {
-               //
-               // Read the data
-               //
-               dataWasReadFlag = true;
-               QString text = readElementText();
-               dataArray->readFromText(text,
-                                       endianName,
-                                       arraySubscriptingOrderForReadingArrayData,
-                                       dataTypeForReadingArrayData,
-                                       dimensionsForReadingArrayData,
-                                       encodingForReadingArrayData,
-                                       externalFileName,
-                                       externalFileOffsetForReadingData);
+                dataWasReadFlag = true;
+                if (this->giftiFile->getReadMetaDataOnlyFlag() == false) {
+                   //
+                   // Read the data
+                   //
+                   QString text = readElementText();
+                   dataArray->readFromText(text,
+                                           endianName,
+                                           arraySubscriptingOrderForReadingArrayData,
+                                           dataTypeForReadingArrayData,
+                                           dimensionsForReadingArrayData,
+                                           encodingForReadingArrayData,
+                                           externalFileName,
+                                           externalFileOffsetForReadingData);
+                }
                
-               //
-               // Add GIFTI array to GIFTI file
-               //
-               giftiFile->addDataArray(dataArray);
+                //
+                // Add GIFTI array to GIFTI file
+                //
+                if (this->giftiDataArrayReadListener != NULL) {
+                   const QString errorMessage =
+                      this->giftiDataArrayReadListener->dataArrayWasRead(
+                         dataArray, this->dataArrayReadIndex, this->numberOfDataArraysInFile);
+                   if (errorMessage.isEmpty() == false) {
+                      raiseError(errorMessage);
+                   }
+                   this->dataArrayReadIndex++;
+                }
+                else {
+                   giftiFile->addDataArray(dataArray);
+                }
             }
             catch (FileException& e) {
                delete dataArray;
