@@ -134,6 +134,7 @@ void
 GiftiLabelTable::clear()
 {
    labels.clear();
+   hadColorsWhenRead = false;
 }
 
 /**
@@ -336,6 +337,7 @@ void
 GiftiLabelTable::copyHelperGiftiLabelTable(const GiftiLabelTable& nlt)
 {
    labels = nlt.labels;
+   hadColorsWhenRead = nlt.hadColorsWhenRead;
 }      
 
 /**
@@ -399,6 +401,17 @@ GiftiLabelTable::createLabelsFromColors(const ColorFile& colorFile)
 void 
 GiftiLabelTable::assignColors(const ColorFile& colorFile)
 {
+   //
+   // Use alpha of zero for ???
+   //
+   bool colorExactMatch = false;
+   unsigned char cur, cug, cub, cua;
+   int colorFileUnknownIndex = colorFile.getColorByName("???",
+                                          colorExactMatch,
+                                          cur, cug, cub, cua);
+   
+   
+   
    unsigned char r, g, b, a;
    GiftiLabelTable::getDefaultColor(r, g, b, a);
    bool exactMatch = false;
@@ -408,18 +421,25 @@ GiftiLabelTable::assignColors(const ColorFile& colorFile)
       int indx = colorFile.getColorByName(labelName,
                                           exactMatch,
                                           r, g, b, a);
-      labels[i].setColorFileIndex(indx);
-      labels[i].setColor(r, g, b, a);
+      if (indx >= 0) {
+          labels[i].setColorFileIndex(indx);
+          labels[i].setColor(r, g, b, a);
+      }
+      else if (colorFileUnknownIndex >= 0) {
+          labels[i].setColorFileIndex(-1);
+          labels[i].setColor(cur, cug, cub, 0);
+      }
    }
    
    //
    // Use alpha of zero for ???
+   // index might change
    //
    int unknownIndex = this->addLabel("???");
    if (unknownIndex >= 0) {
-      float r, g, b, a;
-      this->getColorFloat(unknownIndex, r, g, b, a);
-      this->setColorFloat(unknownIndex, r, r, b, 0.0);
+      float ur, ug, ub, ua;
+      this->getColorFloat(unknownIndex, ur, ug, ub, ua);
+      this->setColorFloat(unknownIndex, ur, ug, ub, 0.0);
    }
 }      
 
@@ -447,7 +467,7 @@ GiftiLabelTable::writeAsXML(QTextStream& stream,
          labels[i].getColorFloat(red, green, blue, alpha);
          GiftiCommon::writeIndentationXML(stream, indent);
          stream << "<" << GiftiCommon::tagLabel << " "
-                << GiftiCommon::attIndex << "=\"" << i << "\" "
+                << GiftiCommon::attKey << "=\"" << i << "\" "
                 << GiftiCommon::attRed << "=\"" << QString::number(red, 'f', 3) << "\" "
                 << GiftiCommon::attGreen << "=\"" << QString::number(green, 'f', 3) << "\" "
                 << GiftiCommon::attBlue << "=\"" << QString::number(blue, 'f', 3) << "\" "
@@ -479,7 +499,7 @@ GiftiLabelTable::writeAsXML(XmlGenericWriter& xmlWriter) const
       labels[i].getColorFloat(red, green, blue, alpha);
 
       XmlGenericWriterAttributes attributes;
-      attributes.addAttribute(GiftiCommon::attIndex, i);
+      attributes.addAttribute(GiftiCommon::attKey, i);
       attributes.addAttribute(GiftiCommon::attRed, red);
       attributes.addAttribute(GiftiCommon::attGreen, green);
       attributes.addAttribute(GiftiCommon::attBlue, blue);
