@@ -35,6 +35,8 @@
 #include "vtkCellArray.h"
 #include "vtkPolyData.h"
 #include "vtkTriangleFilter.h"
+#include <cmath>
+#include <QMutexLocker>
 
 /**
  * Comparison operator for EdgeInfo
@@ -185,8 +187,8 @@ TopologyHelper::TopologyHelper(vtkPolyData* vtkIn,
    
    if (buildNodeInfo) {
       vtkCellArray* polys = vtk->GetPolys();
-      int npts;
-      int* pts;
+      vtkIdType npts;
+      vtkIdType* pts;
       const int maxNodeNum = vtk->GetNumberOfPoints();  //-1;
       for (polys->InitTraversal(); polys->GetNextCell(npts,pts); ) {
          if (npts != 3) {
@@ -216,8 +218,8 @@ TopologyHelper::TopologyHelper(vtkPolyData* vtkIn,
    //
    vtkCellArray* polys = vtk->GetPolys();
    int cellId = 0;
-   int npts;
-   int* pts;
+   vtkIdType npts;
+   vtkIdType* pts;
    for (polys->InitTraversal(); polys->GetNextCell(npts,pts); cellId++) {
       if (npts != 3) {
          std::cerr << " Polygon is not a triangle in TopologyHelper"      
@@ -494,6 +496,122 @@ TopologyHelper::getNodeNeighbors(const int nodeNum,
    }
 }
 
+/**
+ * Get the neighboring nodes for a node, within a given ROI
+ */
+void
+TopologyHelper::getNodeNeighborsInROI(const int nodeNum,
+                                 std::vector<int>& neighborsOut, const float *roiValues) const
+{
+   if ((nodeNum >= 0) && (nodeNum < static_cast<int>(nodes.size()))) {
+      //Since we are restricting to an roi, we need to make sure that the neighbors are within the ROI, and
+      //if not, build a new neighbor list
+      std::vector<int> neighbors = nodes[nodeNum].neighbors;
+      //optimization, first, loop through and see any neighbors are outside the roi
+      bool neighborOutsideOfRoi = false;
+      for(int i = 0;i<neighbors.size();i++)
+      {
+         if(roiValues[neighbors[i]] == 0.0)
+         {
+            neighborOutsideOfRoi = true;
+            break;
+         }
+      }
+
+      if(!neighborOutsideOfRoi)
+      {
+         neighborsOut = nodes[nodeNum].neighbors;
+      }
+      else
+      {
+         neighborsOut.clear();
+
+         for(int i = 0;i<neighbors.size();i++)
+         {
+            if(roiValues[neighbors[i]] == 0.0)//filter out neighbors that are outside of ROI
+            {
+               continue;
+            }
+            else
+            {
+               neighborsOut.push_back(neighbors[i]);
+            }
+         }
+      }
+   }
+   else {
+      neighborsOut.clear();
+   }
+}
+
+/**
+ * Get the neighbors of a node to a specified depth.
+ */
+void 
+TopologyHelper::getNodeNeighborsToDepthIter(const int rootNode, 
+                                        const int depth,
+                                        std::vector<int>& neighborsOut) const
+{
+   if (depth < 2)//could make this function private, and remove this test
+   {//gracefully handle nonpositives, and do 1 the easy way
+      getNodeNeighbors(rootNode, neighborsOut);
+      return;
+   }
+   QMutexLocker locked(&usingMarkNodes);//lock after choosing which version to use, because they are both public
+   int i, j, k;
+   neighborsOut.clear();
+   int numNodes = getNumberOfNodes();
+   int expected = (7 * (depth + 1) * depth) >> 1;//uses bitshift for cheap divide, equals 7 * depth * (depth + 1) / 2
+   if (expected > numNodes) expected = numNodes;
+   neighborsOut.reserve(expected);//reserve means make space, but don't change size()
+   if ((int)markNodes.size() != numNodes)
+   {
+      markNodes.resize(numNodes);
+      for (i = 0; i < numNodes; ++i)
+      {
+         markNodes[i] = 0;
+      }
+   }
+   if ((int)nodelist[0].size() != numNodes)
+   {//WAY overkill in basically all cases, but no way to know max needed for sure, and branching or clear() would be slow
+      nodelist[0].resize(numNodes);
+      nodelist[1].resize(numNodes);
+   }
+   int newind = 1, oldind = 0, whichneigh;
+   int oldused, newused = 1, numNeigh;
+   std::vector<int>* oldlist, *newlist;
+   markNodes[rootNode] = 1;
+   nodelist[0][0] = rootNode;
+   for (i = 0; i < depth; ++i)
+   {
+      oldused = newused;
+      newused = 0;
+      oldlist = nodelist + oldind;//pointer math should be fast
+      newlist = nodelist + newind;
+      for (j = 0; j < oldused; ++j)
+      {
+         const std::vector<int>& neighbors = nodes[(*oldlist)[j]].neighbors;
+         numNeigh = neighbors.size();
+         for (k = 0; k < numNeigh; ++k)
+         {
+            whichneigh = neighbors[k];
+            if (!markNodes[whichneigh])
+            {
+               markNodes[whichneigh] = 1;
+               neighborsOut.push_back(whichneigh);
+               (*newlist)[newused++] = whichneigh;
+            }
+         }
+      }
+      oldind = newind;//swap the lists
+      newind = 1 ^ oldind;//bitwise xor is probably faster than minus
+   }//done, now clean up markNodes
+   numNeigh = neighborsOut.size();
+   for (i = 0; i < numNeigh; ++i)
+      markNodes[neighborsOut[i]] = 0;
+   markNodes[rootNode] = 0;//only zero the nodes that were marked: after completion of call, array will be entirely zeroed
+}
+
 /**
  * Get the neighbors of a node to a specified depth.
  */
@@ -501,6 +619,80 @@ void
 TopologyHelper::getNodeNeighborsToDepth(const int rootNode, 
                                         const int depth,
                                         std::vector<int>& neighborsOut) const
+{
+   if (depth < 2)
+   {//gracefully handle nonpositives, and do 1 the easy way
+      getNodeNeighbors(rootNode, neighborsOut);
+      return;
+   }
+   if (depth > 4)
+   {//iterative version is faster for large depths, cutoff found on 64bit machine, but running 32bit executable
+      getNodeNeighborsToDepthIter(rootNode, depth, neighborsOut);
+      return;
+   }
+   QMutexLocker locked(&usingMarkNodes);//lock after choosing which version to use, because they are both public
+   int i;//otherwise, a quick recursive method
+   neighborsOut.clear();
+   int numNodes = getNumberOfNodes();
+   int expected = (7 * (depth + 1) * depth) >> 1;//uses bitshift for cheap divide, equals 7 * depth * (depth + 1) / 2
+   if (expected > numNodes) expected = numNodes;
+   neighborsOut.reserve(expected);//reserve means make space, but don't change size()
+   if ((int)markNodes.size() != numNodes)
+   {
+      markNodes.resize(numNodes);
+      for (i = 0; i < numNodes; ++i)
+      {
+         markNodes[i] = 0;
+      }
+   }
+   markNodes[rootNode] = depth + 1;
+   depthNeighHelper(rootNode, depth, neighborsOut);//uses depth first graph search: fast, but very unordered, if sorted is desired, sort afterwards
+   int numNeigh = neighborsOut.size();//NOTE: depth first technically "wastes" some effort by searching nodes to a lesser depth then required
+   for (i = 0; i < numNeigh; ++i)
+      markNodes[neighborsOut[i]] = 0;
+   markNodes[rootNode] = 0;//only zero the nodes that were marked: after completion of call, array will be entirely zeroed
+}
+
+void TopologyHelper::depthNeighHelper(int node, int depthrem, std::vector<int>& neighborsOut) const
+{
+   const std::vector<int>& neighbors = nodes[node].neighbors;
+   int i, nextdepth = depthrem - 1, numNeigh = neighbors.size(), thisNeigh, mark;
+   if (nextdepth)
+   {//splitting here removes a large number of recursive calls and compares
+      for (i = 0; i < numNeigh; ++i)
+      {
+         thisNeigh = neighbors[i];
+         mark = markNodes[thisNeigh];
+         if (depthrem > mark)
+         {
+            if (!mark)
+            {
+               neighborsOut.push_back(thisNeigh);
+            }
+            markNodes[thisNeigh] = depthrem;
+            depthNeighHelper(thisNeigh, nextdepth, neighborsOut);
+         }
+      }
+   } else {//same, but don't recurse
+      for (i = 0; i < numNeigh; ++i)
+      {
+         thisNeigh = neighbors[i];
+         if (!markNodes[thisNeigh])
+         {
+            markNodes[thisNeigh] = 1;
+            neighborsOut.push_back(thisNeigh);
+         }
+      }
+   }
+}
+
+/**
+ * Get the neighbors of a node to a specified depth.
+ */
+void 
+TopologyHelper::getNodeNeighborsToDepthOld(const int rootNode, 
+                                        const int depth,
+                                        std::vector<int>& neighborsOut) const
 {
    neighborsOut.clear();
    
