@@ -745,6 +745,12 @@ class VolumeFile : public AbstractFile {
       /// add a region name (returns its index)
       int addRegionName(const QString& name);
       
+      /// set a region name
+      void setRegionName(int index, QString& name);
+
+      /// create region names for voxels that do not index into a region
+      void createRegionNamesForVoxelsThatDoNotIndexIntoRegionNames();
+
       /// synchronize the region names in the volumes (index X is always region Y)
       static void synchronizeRegionNames(std::vector<VolumeFile*>& volumeFiles);
       
@@ -1348,7 +1354,8 @@ class VolumeFile : public AbstractFile {
                                const bool byteSwapNeeded,
                                const bool compressDataWithZlib,
                                gzFile zipStream,
-                               std::ofstream* cppStream) throw (FileException);
+                               std::ofstream* cppStream,
+                               const float divideByThisValue) throw (FileException);
                                 
       /// copy volume data (used by copy contructor and assignment operator)
       void copyVolumeData(const VolumeFile& vf,
